@@ -12,7 +12,7 @@ pub type RawOffset = i64;
 
 /// A zero-indexed line offset into a source file
 #[derive(Clone, Copy, PartialEq, Eq, Hash, PartialOrd, Ord)]
-#[cfg_attr(feature = "serde_derive", derive(Deserialize, Serialize))]
+#[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
 pub struct LineIndex(pub RawIndex);
 
 impl LineIndex {
@@ -50,7 +50,7 @@ impl fmt::Debug for LineIndex {
 
 /// A 1-indexed line number. Useful for pretty printing source locations.
 #[derive(Clone, Copy, PartialEq, Eq, Hash, PartialOrd, Ord)]
-#[cfg_attr(feature = "serde_derive", derive(Deserialize, Serialize))]
+#[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
 pub struct LineNumber(RawIndex);
 
 impl fmt::Debug for LineNumber {
@@ -69,7 +69,7 @@ impl fmt::Display for LineNumber {
 
 /// A line offset in a source file
 #[derive(Clone, Copy, PartialEq, Eq, Hash, PartialOrd, Ord)]
-#[cfg_attr(feature = "serde_derive", derive(Deserialize, Serialize))]
+#[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
 pub struct LineOffset(pub RawOffset);
 
 impl Default for LineOffset {
@@ -94,7 +94,7 @@ impl fmt::Display for LineOffset {
 
 /// A zero-indexed column offset into a source file
 #[derive(Clone, Copy, PartialEq, Eq, Hash, PartialOrd, Ord)]
-#[cfg_attr(feature = "serde_derive", derive(Deserialize, Serialize))]
+#[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
 pub struct ColumnIndex(pub RawIndex);
 
 impl ColumnIndex {
@@ -132,7 +132,7 @@ impl fmt::Debug for ColumnIndex {
 
 /// A 1-indexed column number. Useful for pretty printing source locations.
 #[derive(Clone, Copy, PartialEq, Eq, Hash, PartialOrd, Ord)]
-#[cfg_attr(feature = "serde_derive", derive(Deserialize, Serialize))]
+#[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
 pub struct ColumnNumber(RawIndex);
 
 impl fmt::Debug for ColumnNumber {
@@ -151,7 +151,7 @@ impl fmt::Display for ColumnNumber {
 
 /// A column offset in a source file
 #[derive(Clone, Copy, PartialEq, Eq, Hash, PartialOrd, Ord)]
-#[cfg_attr(feature = "serde_derive", derive(Deserialize, Serialize))]
+#[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
 pub struct ColumnOffset(pub RawOffset);
 
 impl Default for ColumnOffset {
@@ -176,7 +176,7 @@ impl fmt::Display for ColumnOffset {
 
 /// A byte position in a source file
 #[derive(Clone, Copy, PartialEq, Eq, Hash, PartialOrd, Ord)]
-#[cfg_attr(feature = "serde_derive", derive(Deserialize, Serialize))]
+#[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
 pub struct ByteIndex(pub RawIndex);
 
 impl ByteIndex {
@@ -213,7 +213,7 @@ impl fmt::Display for ByteIndex {
 
 /// A byte offset in a source file
 #[derive(Clone, Copy, PartialEq, Eq, Hash, PartialOrd, Ord)]
-#[cfg_attr(feature = "serde_derive", derive(Deserialize, Serialize))]
+#[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
 pub struct ByteOffset(pub RawOffset);
 
 impl ByteOffset {
@@ -252,6 +252,7 @@ impl ByteOffset {
 }
 
 impl Default for ByteOffset {
+    #[inline]
     fn default() -> ByteOffset {
         ByteOffset(0)
     }
@@ -301,14 +302,15 @@ where
 
 macro_rules! impl_index {
     ($Index:ident, $Offset:ident) => {
-
         impl From<RawOffset> for $Offset {
+            #[inline]
             fn from(i: RawOffset) -> Self {
                 $Offset(i)
             }
         }
 
         impl From<RawIndex> for $Index {
+            #[inline]
             fn from(i: RawIndex) -> Self {
                 $Index(i)
             }
@@ -325,12 +327,14 @@ macro_rules! impl_index {
         impl Add<$Offset> for $Index {
             type Output = $Index;
 
+            #[inline]
             fn add(self, rhs: $Offset) -> $Index {
                 $Index((self.0 as RawOffset + rhs.0) as RawIndex)
             }
         }
 
         impl AddAssign<$Offset> for $Index {
+            #[inline]
             fn add_assign(&mut self, rhs: $Offset) {
                 *self = *self + rhs;
             }
@@ -339,6 +343,7 @@ macro_rules! impl_index {
         impl Neg for $Offset {
             type Output = $Offset;
 
+            #[inline]
             fn neg(self) -> $Offset {
                 $Offset(-self.0)
             }
@@ -347,12 +352,14 @@ macro_rules! impl_index {
         impl Add<$Offset> for $Offset {
             type Output = $Offset;
 
+            #[inline]
             fn add(self, rhs: $Offset) -> $Offset {
                 $Offset(self.0 + rhs.0)
             }
         }
 
         impl AddAssign<$Offset> for $Offset {
+            #[inline]
             fn add_assign(&mut self, rhs: $Offset) {
                 self.0 += rhs.0;
             }
@@ -361,12 +368,14 @@ macro_rules! impl_index {
         impl Sub<$Offset> for $Offset {
             type Output = $Offset;
 
+            #[inline]
             fn sub(self, rhs: $Offset) -> $Offset {
                 $Offset(self.0 - rhs.0)
             }
         }
 
         impl SubAssign<$Offset> for $Offset {
+            #[inline]
             fn sub_assign(&mut self, rhs: $Offset) {
                 self.0 -= rhs.0;
             }
@@ -375,6 +384,7 @@ macro_rules! impl_index {
         impl Sub for $Index {
             type Output = $Offset;
 
+            #[inline]
             fn sub(self, rhs: $Index) -> $Offset {
                 $Offset(self.0 as RawOffset - rhs.0 as RawOffset)
             }
@@ -383,12 +393,14 @@ macro_rules! impl_index {
         impl Sub<$Offset> for $Index {
             type Output = $Index;
 
+            #[inline]
             fn sub(self, rhs: $Offset) -> $Index {
                 $Index((self.0 as RawOffset - rhs.0 as RawOffset) as u32)
             }
         }
 
         impl SubAssign<$Offset> for $Index {
+            #[inline]
             fn sub_assign(&mut self, rhs: $Offset) {
                 self.0 = (self.0 as RawOffset - rhs.0) as RawIndex;
             }
